/**
 * This program demonstrates the usage of the RunTimer and CSVWriter
 * classes in order to test the running time of methods. In
 * particular, it will demonstrate how quickly your computer can count
 * to various values.
 */

public class CountTimer {
    /**
     * The maximum value that we will count to
     */
    public static final long N_MAX = 1_000_000_000;

    /**
     * The step size, i.e., the amount by which to increment the count
     */
    public static final long STEP = 10_000_000;

    /**
     * Create a count variable and increment it n times
     */
    static void countTo(long n) {
	long count = 0;
	for (int i = 0; i < n; ++i) {
	    ++count;
	}
    }

    public static void main(String[] args) {
	// make a CSVWriter instance that will create a file called
	// "count-times.csv"
	CSVWriter csv = new CSVWriter("count-times.csv");

	// make a new Timer object
	RunTimer rt = new RunTimer();

	// write first row of csv (column headings)
	csv.addEntry("count");
	csv.addEntry("time (ms)");
	csv.endLine();

	// call the countTo(n) method for various values of n, record
	// the running times, and write these to csv
	for (long n = STEP; n <= N_MAX; n += STEP) {
	    rt.reset(); // reset the RunTimer

	    // start the RunTime, call countTo, and stop the runTimer
	    rt.start(); 
	    countTo(n);
	    rt.stop();

	    // record n and running time (in milliseconds) as a row in csv
	    csv.addEntry(n);
	    csv.addEntry(rt.getElapsedMillis());
	    csv.endLine();
	}
	
	// close and write the csv file!
	csv.close();

	    
    }
}
